@@ -6,6 +6,7 @@ import json
 import os
 import re
 import sys
+import traceback
 import urllib2
 from datetime import datetime
 from math import ceil
@@ -34,7 +35,7 @@ class Debugger(object):
         self.update_hosts()
 
     @staticmethod
-    def _expand_solr_hosts(cmdline_hosts):
+    def _expand_solr_hosts(cmdline_hosts, myself):
         expanded_hosts = []
         if cmdline_hosts:
             if isinstance(cmdline_hosts, str):
@@ -47,11 +48,15 @@ class Debugger(object):
                 try:
                     statuses = urllib2.urlopen('http://%s:8983/solr/admin/collections?action=CLUSTERSTATUS&wt=json' % cmdline_host, timeout=1)
                     for status in json.loads(statuses.read())['cluster'].get('live_nodes', []):
-                        expanded_hosts.append(status.split(':')[0])
+                        live_node = status.split(':')[0]
+                        if live_node != myself:
+                            expanded_hosts.append(live_node)
+                except urllib2.URLError as e:
+                    print('Unable to connect to SolrCloud at %s:8983: %s' % (cmdline_host, e.message))
+                    return []
                 except Exception as e:
                     print('Unable to connect to SolrCloud at %s:8983!' % cmdline_host)
                     raise e
-                    # print(e)
             expanded_hosts.sort()
         if expanded_hosts:
             print('Expanding SolrCloud DNSs from %s to ip list %s' % (', '.join(cmdline_hosts), ', '.join(expanded_hosts)))
@@ -73,6 +78,9 @@ class Debugger(object):
                     statuses = urllib2.urlopen('http://%s:8080/exhibitor/v1/cluster/status' % cmdline_host, timeout=1)
                     for status in json.loads(statuses.read()):
                         expanded_hosts.append(status.get('hostname'))
+                except urllib2.URLError:
+                    print('Unable to connect to Exhibitoe at %s:8080: %s' % e.message)
+                    return []
                 except Exception as e:
                     print('Unable to connect to Exhibitor at %s:8080!' % cmdline_host)
                     print(e)
@@ -93,7 +101,7 @@ class Debugger(object):
             return 'localhost', '127.0.0.1'
 
     def update_hosts(self):
-        self.solrs = self._expand_solr_hosts(self.__solr_hosts)
+        self.solrs = self._expand_solr_hosts(self.__solr_hosts, self.identity[1])
         self.zookeepers = self._expand_zookeeper_hosts(self.__zookeeper_hosts)
 
     def ping_hosts(self, seconds=55):
@@ -116,7 +124,7 @@ class Debugger(object):
                     hosts[host_key]['min'] = float(ping.min_rtt) if float(ping.min_rtt) < hosts[host_key]['min'] else hosts[host_key]['min']
             for zoo in self.zookeepers:
                 host_key = 'ZKPing_%s' % zoo
-                ping = pyping.ping(zoo, count=3, timeout=500, udp=self.use_udp)
+                ping = pyping.ping(zoo, count=5, timeout=500, udp=self.use_udp)
                 if host_key not in hosts:
                     hosts[host_key] = {'avg': 0, 'min': 1000, 'max': 0}
                 if ping.avg_rtt:
@@ -125,8 +133,8 @@ class Debugger(object):
                     hosts[host_key]['max'] = float(ping.max_rtt) if float(ping.max_rtt) > hosts[host_key]['max'] else hosts[host_key]['max']
                 if ping.min_rtt:
                     hosts[host_key]['min'] = float(ping.min_rtt) if float(ping.min_rtt) < hosts[host_key]['min'] else hosts[host_key]['min']
-
             print('.', end="")
+            sys.stdout.flush()
 
             if time() - start < seconds and not self.first_run:
                 sleep(0.5)
@@ -166,7 +174,7 @@ class Debugger(object):
         if max is not None:
             statistic_values['Maximum'] = float(max)
 
-        if statistic_values:
+        if statistic_values and min is not None and max is not None and max > min:
             statistic_values['SampleCount'] = 1
             statistic_values['Sum'] = float(value)
             data['StatisticValues'] = statistic_values
@@ -219,7 +227,6 @@ class Debugger(object):
             for metric_data_slice in [metric_data[i::slices] for i in range(slices)]:
                 response = self.cloudwatch.put_metric_data(Namespace='Search/EC2', MetricData=metric_data_slice)
                 print('Sending statistics, response: %i' % response['ResponseMetadata']['HTTPStatusCode'])
-            sys.stdout.flush()
             self.first_run = False
         except Exception as e:
             print('ERROR SENDING STATISTICS! :( %s' % e.message)
@@ -244,6 +251,9 @@ if __name__ == '__main__':
             debugger.probe()
         except KeyboardInterrupt:
             print('Exiting...')
+            sys.stdout.flush()
             sys.exit(0)
         except Exception as e:
             print('Error: %s' % e.message)
+            traceback.print_exc(file=sys.stdout)
+        sys.stdout.flush()
